"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reader = void 0;
const accounts = require("./accounts");
const assets = require("./assets");
const common = require("./common");
const transactions = require("./transactions");
class Reader {
    constructor(network, algod, indexer) {
        this.algod = algod ?? common.getAlgodClient(network);
        this.indexer = indexer ?? common.getIndexerClient(network);
        this.network = network;
    }
    async validateAddress(address) {
        return accounts.validateAddress(address);
    }
    async getBalanceAlgos(address) {
        return accounts.getBalanceAlgos(this.algod, address);
    }
    async getBalanceMicroalgos(address) {
        return accounts.getBalanceMicroalgos(this.algod, address);
    }
    async getMinBalance(address) {
        return accounts.getMinBalance(this.algod, address);
    }
    async getCreatedAssets(address) {
        return assets.getCreatedAssets(this.algod, address);
    }
    async getAsaBalance(address, asaId) {
        return assets.getAsaBalance(this.algod, address, asaId);
    }
    async isOptIn(address, asaId) {
        return assets.isOptIn(this.algod, address, asaId);
    }
    async getTokenCirculatingSupply(asaId) {
        return assets.getTokenCirculatingSupply(this.algod, asaId);
    }
    async getAssetIdByMetadataHash(hash, creator) {
        return assets.getAssetIdByMetadataHash(this.algod, hash, creator);
    }
    async getAssetMetadata(assetId) {
        return assets.getAssetMetadata(this.indexer, assetId);
    }
    async getPendingTx(address) {
        return transactions.getPendingTxByAddress(this.algod, address);
    }
    async thereArePendingTxs(address) {
        return transactions.thereArePendingTxs(this.algod, address);
    }
}
exports.Reader = Reader;
//# sourceMappingURL=reader.js.map